@@ -6,7 +6,6 @@ import pkg_resources
 import re
 import shutil
 import magic
-from datetime import timezone
 
 from feedgen.feed import FeedGenerator
 from jinja2 import Template
@@ -102,11 +101,11 @@ class Build:
 
     def load_template(self, fname):
         with open(fname, "r") as f:
-            self.template = Template(f.read())
+            self.template = Template(f.read(), autoescape=True)
 
     def load_rss_template(self, fname):
         with open(fname, "r") as f:
-            self.rss_template = Template(f.read())
+            self.rss_template = Template(f.read(), autoescape=True)
 
     def make_filename(self, month, page) -> str:
         fname = "{}{}.html".format(
@@ -143,8 +142,8 @@ class Build:
             e = f.add_entry()
             e.id(url)
             e.title("@{} on {} (#{})".format(m.user.username, m.date, m.id))
-            e.published(m.date.replace(tzinfo=timezone.utc))
             e.link({"href": url})
+            e.published(m.date)
 
             media_mime = ""
             if m.media and m.media.url:
@@ -160,8 +159,8 @@ class Build:
                 e.enclosure(murl, media_size, media_mime)
             e.content(self._make_abstract(m, media_mime), type="html")
 
-        f.rss_file(os.path.join(self.config["publish_dir"], "index.xml"))
-        f.atom_file(os.path.join(self.config["publish_dir"], "index.atom"))
+        f.rss_file(os.path.join(self.config["publish_dir"], "index.xml"), pretty=True)
+        f.atom_file(os.path.join(self.config["publish_dir"], "index.atom"), pretty=True)
 
     def _make_abstract(self, m, media_mime):
         if self.rss_template:
